Description Usage Arguments Value Author(s) Examples
Shuffle genomic regions among a defined genome.
1 2 |
regions |
The genomic ranges object containing the genomic regions to shuffle. |
chromSizes=LoadChromSizes("hg38") |
A vector containing all the chromosome lengths for the species in consideration. |
universe=NULL |
A set of genomic regions that prevent shuffles for occuring outside of it. |
included=1 |
Represents the fraction of each regions that can be outside of the universe. |
byChrom=FALSE |
Will the shuffles stay in the chromosome they originate (TRUE) or can they be placed everywhere on the genome (FALSE) |
A genomic ranges containing the new shuffled chromosic regions.
Zacharie Menetrier
1 2 3 4 | regionsFile <- system.file("extdata", "ReMap_nrPeaks_public_chr22.bed",
package = "ReMapEnrich")
regions <- bedToGranges(regionsFile)
shuffledRegions <- shuffle(regions)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.